@@ -1,6 +1,5 @@
 module SimpleTraits
 using MacroTools
-const curmod = nameof(@__MODULE__)
 import InteractiveUtils
 
 # This is basically just adding a few convenience functions & macros
@@ -80,7 +79,7 @@ istrait(Tr1{Int,Float64}) => return true or false
 """
 istrait(::Any) = error("Argument is not a Trait.")
 istrait(tr::Type{T}) where {T<:Trait} = trait(tr)==stripNot(tr) ? true : false # Problem, this can run into issue #265
-                                                                        # thus is redefine when traits are defined
+# thus is redefine when traits are defined
 """
 
 Used to define a trait.  Traits, like types, are camel cased.  I
@@ -139,13 +138,13 @@ macro traitimpl(tr)
         trname = esc(tr.args[1])
         curly = Any[]
         paras = Any[]
-        for (ty,v) in zip(typs, GenerateTypeVars{:upcase}())
+        for (ty, v) in zip(typs, GenerateTypeVars{:upcase}())
             push!(curly, Expr(:(<:), esc(v), esc(ty)))  #:($v<:$ty)
             push!(paras, esc(v))
         end
         arg = :(::Type{$trname{$(paras...)}})
-        fnhead = :($curmod.trait($arg) where {$(curly...)})
-        isfnhead = :($curmod.istrait($arg) where {$(curly...)})
+        fnhead = :(SimpleTraits.trait($arg) where {$(curly...)})
+        isfnhead = :(SimpleTraits.istrait($arg) where {$(curly...)})
         if !negated
             return quote
                 $fnhead = $trname{$(paras...)}
@@ -158,19 +157,21 @@ macro traitimpl(tr)
             end
         end
     elseif tr.head==:call
-        @assert tr.args[1]==:<
-        negated,Tr,P1,fn,P2 = @match tr begin
-            Not{Tr_{P1__}} <- fn_(P2__) => (true, Tr, P1, fn, P2)
-            Tr_{P1__} <- fn_(P2__) => (false, Tr, P1, fn, P2)
+        @assert tr.args[1]==:< || tr.args[1]==:←
+        negated, Tr, P1, fn, P2 = @match tr begin
+            Not{Tr_{P1__}} < - fn_(P2__) => (true, Tr, P1, fn, P2)
+            Tr_{P1__} < - fn_(P2__)      => (false, Tr, P1, fn, P2)
+            Not{Tr_{P1__}} ← fn_(P2__) => (true, Tr, P1, fn, P2)
+            Tr_{P1__} ← fn_(P2__)      => (false, Tr, P1, fn, P2)
         end
         if negated
             fn = Expr(:call, GlobalRef(SimpleTraits, :!), fn)
         end
         return esc(quote
-                   function SimpleTraits.trait(::Type{$Tr{$(P1...)}}) where {$(P1...)}
-                       return $fn($(P2...)) ? $Tr{$(P1...)} : Not{$Tr{$(P1...)}}
-                   end
-                   nothing
+                       function SimpleTraits.trait(::Type{$Tr{$(P1...)}}) where {$(P1...)}
+                           return $fn($(P2...)) ? $Tr{$(P1...)} : SimpleTraits.Not{$Tr{$(P1...)}}
+                       end
+                       nothing
                    end)
     else
         error("Cannot parse $tr")
@@ -216,10 +217,10 @@ let
 
         # TODO 1.0: remove
         out = @match fhead begin
-            f_(args0__; kwargs__)               => (f,[],args0,kwargs)
-            f_(args0__)                         => (f,[],args0,[])
-            f_(args0__; kwargs__) where paras__ => (f,paras,args0,kwargs)
-            f_(args0__) where paras__           => (f,paras,args0,[])
+            f_(args0__; kwargs__)                 => (f, [], args0, kwargs)
+            f_(args0__)                           => (f, [], args0, [])
+            f_(args0__; kwargs__) where {paras__} => (f, paras, args0, kwargs)
+            f_(args0__) where {paras__}           => (f, paras, args0, [])
         end
         if out==nothing
             error("Could not parse function-head: $fhead. Note that several `where` are not supported.")
@@ -265,23 +266,23 @@ let
                     a = a.args[1]
                 end
                 out = @match a begin
-                    ::::Tr_           => (nothing,nothing,Tr)
-                    ::T_::Tr_         => (nothing,T,Tr)
-                    x_Symbol::::Tr_   => (x,nothing,Tr)
-                    x_Symbol::T_::Tr_ => (x,T,Tr)
+                    ::::Tr_           => (nothing, nothing, Tr)
+                    ::T_::Tr_         => (nothing, T, Tr)
+                    x_Symbol::::Tr_   => (x, nothing, Tr)
+                    x_Symbol::T_::Tr_ => (x, T, Tr)
                 end
                 out!=nothing && break
             end
             out==nothing && error("No trait found in function signature")
-            arg,typ,trait0 = out
+            arg, typ, trait0 = out
             if typ===nothing # case `f(x::::Tr)`
                 typ = gensym()
                 push!(typs, typ)
             elseif length(typs)==0 # case `f(x::Integer::Tr)`
-                    # needs to be put into `f(x::I::Tr) where I<:Integer`
-                    typ_ = typ
-                    typ = gensym()
-                    push!(typs, :($typ<:$typ_))
+                # needs to be put into `f(x::I::Tr) where I<:Integer`
+                typ_ = typ
+                typ = gensym()
+                push!(typs, :($typ<:$typ_))
             end
             # Note other cases, e.g.
             # f(x::T::Tr) where T
@@ -309,7 +310,7 @@ let
         if isnegated(trait)
             trait0_opposite = trait0 # opposite of `trait` below as that gets stripped of !
             trait = trait.args[2]
-            val = :(::Type{$curmod.Not{$trait}})
+            val = :(::Type{SimpleTraits.Not{$trait}})
         else
             trait0_opposite = Expr(:call, :!, trait0)  # generate the opposite
             val = :(::Type{$trait})
@@ -328,18 +329,15 @@ let
             dispatch_cache[key] = (haskwargs, args0)
             if !haskwargs
                 quote
-                    $fname($(args1...)) where {$(typs...)} = (Base.@_inline_meta(); $fname($curmod.trait($trait),
-                                                                                           $(strip_tpara(strip_kw(args1))...)
-                                                                                           )
-                                                              )
+                    $fname($(args1...)) where {$(typs...)} = (Base.@_inline_meta(); $fname(SimpleTraits.trait($trait),
+                                                                                           $(strip_tpara(strip_kw(args1))...)))
                 end
             else
                 quote
-                    $fname($(args1...);kwargs...) where {$(typs...)} = (Base.@_inline_meta(); $fname($curmod.trait($trait),
-                                                                                                     $(strip_tpara(strip_kw(args1))...);
-                                                                                                     kwargs...
-                                                                                                     )
-                                                                        )
+                    $fname($(args1...); kwargs...) where {$(typs...)} = (Base.@_inline_meta();
+                                                                         $fname(SimpleTraits.trait($trait),
+                                                                                $(strip_tpara(strip_kw(args1))...);
+                                                                                kwargs...))
                 end
             end
         else # trait dispatch function already defined
@@ -359,8 +357,8 @@ let
             nothing # dispatchfn
         end
         return rmlines(quote
-                       $dispatchfn
-                       Base.@__doc__ $ex
+                           $dispatchfn
+                           Base.@__doc__ $ex
                        end)
     end
 end
@@ -407,7 +405,6 @@ function strip_tpara(a::Expr)
     end
 end
 
-
 # [:(x::X=4)] -> [:x::X]
 # i.e. strips defaults arguments
 # also takes care of :...
@@ -424,7 +421,6 @@ function strip_kw(a::Expr)
     end
 end
 
-
 # insert dummy: ::X -> gensym()::X
 # also takes care of :...
 # not needed for kwargs
@@ -471,7 +467,6 @@ findline(arg) = nothing
 #     @assert llvm_lines(fn_test, Args) == nlines
 # end
 
-
 """
     check_fast_traitdispatch(Tr, Args=(Int,), nlines=6, verbose=false)
 
@@ -509,17 +504,17 @@ macro check_fast_traitdispatch(Tr, Arg=:Int, verbose=false)
     nl_null = gensym()
     out = gensym()
     esc(quote
-        $test_fn_null(x) = 1
-        $nl_null = SimpleTraits.llvm_lines($test_fn_null, ($Arg,))
-        @traitfn $test_fn(x::::$Tr) = 1
-        @traitfn $test_fn(x::::(!$Tr)) = 2
-        $nl = SimpleTraits.llvm_lines($test_fn, ($Arg,))
-        $out = $nl == $nl_null
-        if $verbose && !$out
-            println("Number of llvm code lines $($nl) but should be $($nl_null).")
-        end
-        $out
-    end)
+            $test_fn_null(x) = 1
+            $nl_null = SimpleTraits.llvm_lines($test_fn_null, ($Arg,))
+            @traitfn $test_fn(x::::$Tr) = 1
+            @traitfn $test_fn(x::::(!$Tr)) = 2
+            $nl = SimpleTraits.llvm_lines($test_fn, ($Arg,))
+            $out = $nl == $nl_null
+            if $verbose && !$out
+                println("Number of llvm code lines $($nl) but should be $($nl_null).")
+            end
+            $out
+        end)
 end
 
 "Returns number of llvm-IR lines for a call of function `fn` with argument types `args`"
